package at.jku.ssw.graphviz;

import at.jku.ssw.Iterator;
import at.jku.ssw.graph.Edge;
import at.jku.ssw.graph.Graph;
import at.jku.ssw.graph.Vertex;

class DotMakerGraph {
	private final Graph graph;
	private final StringBuilder b = new StringBuilder();

	DotMakerGraph(Graph graph) {
		this.graph = graph;
	}

	String getDot() {
		b.append("digraph MyGraph {\n");
		Iterator it = graph.vertices.iterator();
		while (it.hasNext()) {
			vertex((Vertex) it.next());
		}
		it = graph.edges.iterator();
		while (it.hasNext()) {
			edge((Edge) it.next());
		}
		b.append("}");
		return b.toString();
	}

	private void vertex(Vertex v) {
		b.append(v.value + ";\n");
	}

	private void edge(Edge e) {
		b.append(e.start.value);
		b.append("->");
		b.append(e.end.value);
		b.append("[");
		if (e.weight != 0) {
			b.append(String.format("label=\"%d\",", e.weight));
		}
		switch (e.kind) {
		case Directed:
			b.append("dir=forward,");
			break;
		case Undirected:
			b.append("dir=none,");
			break;
		default:
			throw new UnsupportedOperationException();
		}
		b.append("]");
		b.append(";\n");
	}
}